
Summary:          An optimized BLAS library based on GotoBLAS2
Name:             openblas
Version:          0.3.28
Release:          1
License:          BSD
Group:            Development/Libraries
URL:              https://github.com/OpenMathLib/OpenBLAS
Source0:          https://github.com/OpenMathLib/OpenBLAS/releases/download/v%{version}/OpenBLAS-%{version}.tar.gz

Patch0:           openblas-0.3.28-aix-gcc.patch

BuildRequires: m4
BuildRequires: gcc-gfortran >= 10.3.0
BuildRequires: libgomp >= 10.3.0

Requires: libgcc >= 10.3.0
Requires: libgfortran >= 10.3.0
Requires: libgomp >= 10.3.0

%description
OpenBLAS is an optimized BLAS library based on GotoBLAS2 1.13 BSD version.
It is an open source implementation of the BLAS (Basic Linear Algebra 
Subprograms) API with many hand-crafted optimizations for specific 
processor types. OpenBLAS adds optimized implementations of linear 
algebra kernels for several processor architectures.

This version is built with DYNAMIC_ARCH support. Hence it will dynamically 
detect the Processor version (POWER7, POWER8, POWER9, POWER10) running 
on the machine and uses the optimized code for that Processor.

%package devel
Group: Development/Libraries
Summary: An optimized BLAS library based on GotoBLAS2 - development files
Requires: %{name} = %{version}-%{release}

%description devel
Development files for OpenBLAS.


%prep
%setup -q -n OpenBLAS-%{version}
%patch0 -p1

# Duplicate source for 32 & 64 bits
rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -rf ..?* .[!.]* *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit


%build

# Build 32bit 
cd 32bit
export CC="gcc -pthread -D_LARGE_FILES"
export FC="gfortran -pthread -D_LARGE_FILES"
export LDFLAGS="-Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"

# 32bit build still uses POWER6 gemm kernels
(gmake TARGET=POWER6 BINARY=32 USE_OPENMP=1 USE_THREAD=1 || true)

# Build 64bit
cd ../64bit
export CC="gcc -pthread -maix64"
export FC="gfortran -pthread -maix64"
export OBJECT_MODE=64
export LDFLAGS="-Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib:/usr/lib:/lib"

gmake TARGET=POWER7 BINARY=64 USE_OPENMP=1 USE_THREAD=1 DYNAMIC_ARCH=1


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

# Install 64bit only as we need only the *.so.0 from 32bit directory
cd 64bit
export CC="gcc -pthread -maix64"
export FC="gfortran -pthread -maix64"
export OBJECT_MODE=64
export LDFLAGS="-Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib:/usr/lib:/lib"

gmake OPENBLAS_INCLUDE_DIR=%{_includedir}/openblas TARGET=POWER7 BINARY=64 \
           USE_OPENMP=1 USE_THREAD=1 DYNAMIC_ARCH=1 install DESTDIR=${RPM_BUILD_ROOT} PREFIX=%{_prefix}

/usr/bin/rm ${RPM_BUILD_ROOT}%{_libdir}/libopenblas.a
/usr/bin/ar -q ${RPM_BUILD_ROOT}%{_libdir}/libopenblas.a ${RPM_BUILD_ROOT}%{_libdir}/libopenblas.so.0

# Copy 32bit library to the archive
cd ../32bit
/usr/bin/ar -X32 -q ${RPM_BUILD_ROOT}%{_libdir}/libopenblas.a libopenblas.so.0


%files
%defattr(-,root,system,-)
%doc 32bit/LICENSE 32bit/README.md 32bit/USAGE.md 32bit/GotoBLAS_00License.txt
%{_libdir}/libopenblas.a

%files devel
%defattr(-,root,system,-)
%{_includedir}/openblas
%{_libdir}/cmake/openblas
%{_libdir}/pkgconfig/openblas.pc


%changelog
* Fri Sep 06 2024 Ayappan Perumal <ayappap2@in.ibm.com> - 0.3.28-1
- Update version to 0.3.28
- Build with DYNAMIC_ARCH

* Tue Nov 16 2021 Ayappan P <ayappap2@in.ibm.com> - 0.3.18-1
- Update to 0.3.18
- Add support for Power10

* Tue May 18 2021 Ayappan P <ayappap2@in.ibm.com> - 0.3.15-1
- Update to 0.3.15

* Fri Jun 26 2020 Étienne Guesnet <etienne.guesnet.external@atos.net> - 0.3.10-1
- New version 0.3.10
- Add 32bits
- Add check section
- Add devel subpackage
- 32 bit is available only on POWER 6

* Thu Aug 29 2019 Ayappan P <ayappap2@in.ibm.com> - 0.3.6-1
- Update to 0.3.6
- Power8 code build as well

* Wed Mar 20 2019 Ayappan P <ayappap2@in.ibm.com> - 0.3.5-1
- First port to AIX Toolbox
